@@ -40,7 +40,10 @@ dojo.declare("dojo.data.ItemFileReadStore", null,{
 		this._arrayOfTopLevelItems = [];
 		this._loadFinished = false;
 		this._jsonFileUrl = keywordParameters.url;
+		this._ccUrl = keywordParameters.url;
+		this.url = keywordParameters.url;
 		this._jsonData = keywordParameters.data;
+		this.data = null;
 		this._datatypeMap = keywordParameters.typeMap || {};
 		if(!this._datatypeMap['Date']){
 			//If no default mapping for dates, then set this as default.
@@ -55,16 +58,57 @@ dojo.declare("dojo.data.ItemFileReadStore", null,{
 		}
 		this._features = {'dojo.data.api.Read':true, 'dojo.data.api.Identity':true};
 		this._itemsByIdentity = null;
-		this._storeRefPropName = "_S";  // Default name for the store reference to attach to every item.
+		this._storeRefPropName = "_S"; // Default name for the store reference to attach to every item.
 		this._itemNumPropName = "_0"; // Default Item Id for isItem to attach to every item.
 		this._rootItemPropName = "_RI"; // Default Item Id for isItem to attach to every item.
 		this._reverseRefMap = "_RRM"; // Default attribute for constructing a reverse reference map for use with reference integrity
-		this._loadInProgress = false;	//Got to track the initial load to prevent duelling loads of the dataset.
+		this._loadInProgress = false; //Got to track the initial load to prevent duelling loads of the dataset.
 		this._queuedFetches = [];
+		if(keywordParameters.urlPreventCache !== undefined){
+			this.urlPreventCache = keywordParameters.urlPreventCache?true:false;
+		}
+		if(keywordParameters.hierarchical !== undefined){
+			this.hierarchical = keywordParameters.hierarchical?true:false;
+		}
+		if(keywordParameters.clearOnClose){
+			this.clearOnClose = true;
+		}
+		if("failOk" in keywordParameters){
+			this.failOk = keywordParameters.failOk?true:false;
+		}
 	},
 	
 	url: "",	// use "" rather than undefined for the benefit of the parser (#3539)
 
+	//Internal var, crossCheckUrl.  Used so that setting either url or _jsonFileUrl, can still trigger a reload
+	//when clearOnClose and close is used.
+	_ccUrl: "",
+
+	data: null,	// define this so that the parser can populate it
+
+	typeMap: null, //Define so parser can populate.
+	
+	//Parameter to allow users to specify if a close call should force a reload or not.
+	//By default, it retains the old behavior of not clearing if close is called.  But
+	//if set true, the store will be reset to default state.  Note that by doing this,
+	//all item handles will become invalid and a new fetch must be issued.
+	clearOnClose: false,
+
+	//Parameter to allow specifying if preventCache should be passed to the xhrGet call or not when loading data from a url.  
+	//Note this does not mean the store calls the server on each fetch, only that the data load has preventCache set as an option.
+	//Added for tracker: #6072
+	urlPreventCache: false,
+	
+	//Parameter for specifying that it is OK for the xhrGet call to fail silently.
+	failOk: false,
+
+	//Parameter to indicate to process data from the url as hierarchical 
+	//(data items can contain other data items in js form).  Default is true 
+	//for backwards compatibility.  False means only root items are processed 
+	//as items, all child objects outside of type-mapped objects and those in 
+	//specific reference format, are left straight JS data objects.
+	hierarchical: true,
+
 	_assertIsItem: function(/* item */ item){
 		//	summary:
 		//		This function tests whether the item passed in is indeed an item in the store.
@@ -101,7 +145,8 @@ dojo.declare("dojo.data.ItemFileReadStore", null,{
 
 		this._assertIsItem(item);
 		this._assertIsAttribute(attribute);
-		return item[attribute] || []; // Array
+		// Clone it before returning.  refs: #10474
+		return (item[attribute] || []).slice(0); // Array
 	},
 
 	getAttributes: function(/* item */ item){
@@ -119,10 +164,12 @@ dojo.declare("dojo.data.ItemFileReadStore", null,{
 	},
 
 	hasAttribute: function(	/* item */ item,
-							/* attribute-name-string */ attribute) {
+							/* attribute-name-string */ attribute){
 		//	summary: 
 		//		See dojo.data.api.Read.hasAttribute()
-		return this.getValues(item, attribute).length > 0;
+		this._assertIsItem(item);
+		this._assertIsAttribute(attribute);
+		return (attribute in item);
 	},
 
 	containsValue: function(/* item */ item, 
@@ -220,31 +267,34 @@ dojo.declare("dojo.data.ItemFileReadStore", null,{
 							/* Function */ errorCallback){
 		//	summary: 
 		//		See dojo.data.util.simpleFetch.fetch()
-		var self = this;
-		var filter = function(requestArgs, arrayOfItems){
-			var items = [];
+		var self = this,
+		    filter = function(requestArgs, arrayOfItems){
+			var items = [],
+			    i, key;
 			if(requestArgs.query){
-				var ignoreCase = requestArgs.queryOptions ? requestArgs.queryOptions.ignoreCase : false; 
+				var value,
+				    ignoreCase = requestArgs.queryOptions ? requestArgs.queryOptions.ignoreCase : false;
 
 				//See if there are any string values that can be regexp parsed first to avoid multiple regexp gens on the
 				//same value for each item examined.  Much more efficient.
 				var regexpList = {};
-				for(var key in requestArgs.query){
-					var value = requestArgs.query[key];
+				for(key in requestArgs.query){
+					value = requestArgs.query[key];
 					if(typeof value === "string"){
 						regexpList[key] = dojo.data.util.filter.patternToRegExp(value, ignoreCase);
+					}else if(value instanceof RegExp){
+						regexpList[key] = value;
 					}
 				}
-
-				for(var i = 0; i < arrayOfItems.length; ++i){
+				for(i = 0; i < arrayOfItems.length; ++i){
 					var match = true;
 					var candidateItem = arrayOfItems[i];
 					if(candidateItem === null){
 						match = false;
 					}else{
-						for(var key in requestArgs.query) {
-							var value = requestArgs.query[key];
-							if (!self._containsValue(candidateItem, key, value, regexpList[key])){
+						for(key in requestArgs.query){
+							value = requestArgs.query[key];
+							if(!self._containsValue(candidateItem, key, value, regexpList[key])){
 								match = false;
 							}
 						}
@@ -260,7 +310,7 @@ dojo.declare("dojo.data.ItemFileReadStore", null,{
 				// can get lists and sort without affecting each other.  We also need to
 				// filter out any null values that have been left as a result of deleteItem()
 				// calls in ItemFileWriteStore.
-				for(var i = 0; i < arrayOfItems.length; ++i){
+				for(i = 0; i < arrayOfItems.length; ++i){
 					var item = arrayOfItems[i];
 					if(item !== null){
 						items.push(item);
@@ -273,6 +323,28 @@ dojo.declare("dojo.data.ItemFileReadStore", null,{
 		if(this._loadFinished){
 			filter(keywordArgs, this._getItemsArray(keywordArgs.queryOptions));
 		}else{
+			//Do a check on the JsonFileUrl and crosscheck it.
+			//If it doesn't match the cross-check, it needs to be updated
+			//This allows for either url or _jsonFileUrl to he changed to
+			//reset the store load location.  Done this way for backwards 
+			//compatibility.  People use _jsonFileUrl (even though officially
+			//private.
+			if(this._jsonFileUrl !== this._ccUrl){
+				dojo.deprecated("dojo.data.ItemFileReadStore: ", 
+					"To change the url, set the url property of the store," +
+					" not _jsonFileUrl.  _jsonFileUrl support will be removed in 2.0");
+				this._ccUrl = this._jsonFileUrl;
+				this.url = this._jsonFileUrl;
+			}else if(this.url !== this._ccUrl){
+				this._jsonFileUrl = this.url;
+				this._ccUrl = this.url;
+			}
+
+			//See if there was any forced reset of data.
+			if(this.data != null && this._jsonData == null){
+				this._jsonData = this.data;
+				this.data = null;
+			}
 
 			if(this._jsonFileUrl){
 				//If fetches come in before the loading has finished, but while
@@ -284,7 +356,9 @@ dojo.declare("dojo.data.ItemFileReadStore", null,{
 					this._loadInProgress = true;
 					var getArgs = {
 							url: self._jsonFileUrl, 
-							handleAs: "json-comment-optional"
+							handleAs: "json-comment-optional",
+							preventCache: this.urlPreventCache,
+							failOk: this.failOk
 						};
 					var getHandler = dojo.xhrGet(getArgs);
 					getHandler.addCallback(function(data){
@@ -305,6 +379,25 @@ dojo.declare("dojo.data.ItemFileReadStore", null,{
 						self._loadInProgress = false;
 						errorCallback(error, keywordArgs);
 					});
+
+					//Wire up the cancel to abort of the request
+					//This call cancel on the deferred if it hasn't been called
+					//yet and then will chain to the simple abort of the
+					//simpleFetch keywordArgs
+					var oldAbort = null;
+					if(keywordArgs.abort){
+						oldAbort = keywordArgs.abort;
+					}
+					keywordArgs.abort = function(){
+						var df = getHandler;
+						if(df && df.fired === -1){
+							df.cancel();
+							df = null;
+						}
+						if(oldAbort){
+							oldAbort.call(keywordArgs);
+						}
+					};
 				}
 			}else if(this._jsonData){
 				try{
@@ -325,11 +418,11 @@ dojo.declare("dojo.data.ItemFileReadStore", null,{
 		//	summary: 
 		//		Internal function to execute delayed request in the store.
 		//Execute any deferred fetches now.
-		if (this._queuedFetches.length > 0) {
+		if(this._queuedFetches.length > 0){
 			for(var i = 0; i < this._queuedFetches.length; i++){
-				var fData = this._queuedFetches[i];
-				var delayedQuery = fData.args;
-				var delayedFilter = fData.filter;
+				var fData = this._queuedFetches[i],
+				    delayedQuery = fData.args,
+				    delayedFilter = fData.filter;
 				if(delayedFilter){
 					delayedFilter(delayedQuery, this._getItemsArray(delayedQuery.queryOptions)); 
 				}else{
@@ -344,7 +437,7 @@ dojo.declare("dojo.data.ItemFileReadStore", null,{
 		//	summary: 
 		//		Internal function to determine which list of items to search over.
 		//	queryOptions: The query options parameter, if any.
-		if(queryOptions && queryOptions.deep) {
+		if(queryOptions && queryOptions.deep){
 			return this._arrayOfAllItems; 
 		}
 		return this._arrayOfTopLevelItems;
@@ -353,6 +446,29 @@ dojo.declare("dojo.data.ItemFileReadStore", null,{
 	close: function(/*dojo.data.api.Request || keywordArgs || null */ request){
 		 //	summary: 
 		 //		See dojo.data.api.Read.close()
+		 if(this.clearOnClose && 
+			this._loadFinished && 
+			!this._loadInProgress){
+			 //Reset all internalsback to default state.  This will force a reload
+			 //on next fetch.  This also checks that the data or url param was set 
+			 //so that the store knows it can get data.  Without one of those being set,
+			 //the next fetch will trigger an error.
+
+			 if(((this._jsonFileUrl == "" || this._jsonFileUrl == null) && 
+				 (this.url == "" || this.url == null)
+				) && this.data == null){
+				 console.debug("dojo.data.ItemFileReadStore: WARNING!  Data reload " +
+					" information has not been provided." + 
+					"  Please set 'url' or 'data' to the appropriate value before" +
+					" the next fetch");
+			 }
+			 this._arrayOfAllItems = [];
+			 this._arrayOfTopLevelItems = [];
+			 this._loadFinished = false;
+			 this._itemsByIdentity = null;
+			 this._loadInProgress = false;
+			 this._queuedFetches = [];
+		 }
 	},
 
 	_getItemsFromLoadedData: function(/* Object */ dataObject){
@@ -368,6 +484,8 @@ dojo.declare("dojo.data.ItemFileReadStore", null,{
 		//		Array of items in store item format.
 		
 		// First, we define a couple little utility functions...
+		var addingArrays = false,
+		    self = this;
 		
 		function valueIsAnItem(/* anything */ aValue){
 			// summary:
@@ -384,19 +502,19 @@ dojo.declare("dojo.data.ItemFileReadStore", null,{
 			// 	|	true == valueIsAnItem({iggy:'pop'});
 			// 	|	true == valueIsAnItem({foo:42});
 			var isItem = (
-				(aValue != null) &&
-				(typeof aValue == "object") &&
-				(!dojo.isArray(aValue)) &&
+				(aValue !== null) &&
+				(typeof aValue === "object") &&
+				(!dojo.isArray(aValue) || addingArrays) &&
 				(!dojo.isFunction(aValue)) &&
-				(aValue.constructor == Object) &&
-				(typeof aValue._reference == "undefined") && 
-				(typeof aValue._type == "undefined") && 
-				(typeof aValue._value == "undefined")
+				(aValue.constructor == Object || dojo.isArray(aValue)) &&
+				(typeof aValue._reference === "undefined") && 
+				(typeof aValue._type === "undefined") && 
+				(typeof aValue._value === "undefined") &&
+				self.hierarchical
 			);
 			return isItem;
 		}
 		
-		var self = this;
 		function addItemAndSubItemsToArrayOfAllItems(/* Item */ anItem){
 			self._arrayOfAllItems.push(anItem);
 			for(var attribute in anItem){
@@ -426,13 +544,16 @@ dojo.declare("dojo.data.ItemFileReadStore", null,{
 		// to work with in memory.
 
 		// Step 1: Walk through the object hierarchy and build a list of all items
-		var i;
-		var item;
+		var i,
+		    item;
 		this._arrayOfAllItems = [];
 		this._arrayOfTopLevelItems = dataObject.items;
 
 		for(i = 0; i < this._arrayOfTopLevelItems.length; ++i){
 			item = this._arrayOfTopLevelItems[i];
+			if(dojo.isArray(item)){
+				addingArrays = true;
+			}
 			addItemAndSubItemsToArrayOfAllItems(item);
 			item[this._rootItemPropName]=true;
 		}
@@ -445,14 +566,13 @@ dojo.declare("dojo.data.ItemFileReadStore", null,{
 		// 
 		// We also store the attribute names so we can validate our store  
 		// reference and item id special properties for the O(1) isItem
-		var allAttributeNames = {};
-		var key;
+		var allAttributeNames = {},
+		    key;
 
 		for(i = 0; i < this._arrayOfAllItems.length; ++i){
 			item = this._arrayOfAllItems[i];
 			for(key in item){
-				if (key !== this._rootItemPropName)
-				{
+				if(key !== this._rootItemPropName){
 					var value = item[key];
 					if(value !== null){
 						if(!dojo.isArray(value)){
@@ -533,10 +653,10 @@ dojo.declare("dojo.data.ItemFileReadStore", null,{
 			item = this._arrayOfAllItems[i]; // example: { name:['Kermit'], friends:[{_reference:{name:'Miss Piggy'}}] }
 			for(key in item){
 				arrayOfValues = item[key]; // example: [{_reference:{name:'Miss Piggy'}}]
-				for(var j = 0; j < arrayOfValues.length; ++j) {
+				for(var j = 0; j < arrayOfValues.length; ++j){
 					value = arrayOfValues[j]; // example: {_reference:{name:'Miss Piggy'}}
 					if(value !== null && typeof value == "object"){
-						if(value._type && value._value){
+						if(("_type" in value) && ("_value" in value)){
 							var type = value._type; // examples: 'Date', 'Color', or 'ComplexNumber'
 							var mappingObj = this._datatypeMap[type]; // examples: Date, dojo.Color, foo.math.ComplexNumber, {type: dojo.Color, deserialize(value){ return new dojo.Color(value)}}
 							if(!mappingObj){ 
@@ -554,13 +674,13 @@ dojo.declare("dojo.data.ItemFileReadStore", null,{
 							if(!dojo.isObject(referenceDescription)){
 								// example: 'Miss Piggy'
 								// from an item like: { name:['Kermit'], friends:[{_reference:'Miss Piggy'}]}
-								arrayOfValues[j] = this._itemsByIdentity[referenceDescription];
+								arrayOfValues[j] = this._getItemByIdentity(referenceDescription);
 							}else{
 								// example: {name:'Miss Piggy'}
 								// from an item like: { name:['Kermit'], friends:[{_reference:{name:'Miss Piggy'}}] }
 								for(var k = 0; k < this._arrayOfAllItems.length; ++k){
-									var candidateItem = this._arrayOfAllItems[k];
-									var found = true;
+									var candidateItem = this._arrayOfAllItems[k],
+									    found = true;
 									for(var refKey in referenceDescription){
 										if(candidateItem[refKey] != referenceDescription[refKey]){ 
 											found = false; 
@@ -626,8 +746,33 @@ dojo.declare("dojo.data.ItemFileReadStore", null,{
 		//		See dojo.data.api.Identity.fetchItemByIdentity()
 
 		// Hasn't loaded yet, we have to trigger the load.
+		var item,
+		    scope;
 		if(!this._loadFinished){
 			var self = this;
+			//Do a check on the JsonFileUrl and crosscheck it.
+			//If it doesn't match the cross-check, it needs to be updated
+			//This allows for either url or _jsonFileUrl to he changed to
+			//reset the store load location.  Done this way for backwards 
+			//compatibility.  People use _jsonFileUrl (even though officially
+			//private.
+			if(this._jsonFileUrl !== this._ccUrl){
+				dojo.deprecated("dojo.data.ItemFileReadStore: ", 
+					"To change the url, set the url property of the store," +
+					" not _jsonFileUrl.  _jsonFileUrl support will be removed in 2.0");
+				this._ccUrl = this._jsonFileUrl;
+				this.url = this._jsonFileUrl;
+			}else if(this.url !== this._ccUrl){
+				this._jsonFileUrl = this.url;
+				this._ccUrl = this.url;
+			}
+			
+			//See if there was any forced reset of data.
+			if(this.data != null && this._jsonData == null){
+				this._jsonData = this.data;
+				this.data = null;
+			}
+
 			if(this._jsonFileUrl){
 
 				if(this._loadInProgress){
@@ -636,16 +781,18 @@ dojo.declare("dojo.data.ItemFileReadStore", null,{
 					this._loadInProgress = true;
 					var getArgs = {
 							url: self._jsonFileUrl, 
-							handleAs: "json-comment-optional"
+							handleAs: "json-comment-optional",
+							preventCache: this.urlPreventCache,
+							failOk: this.failOk
 					};
 					var getHandler = dojo.xhrGet(getArgs);
 					getHandler.addCallback(function(data){
-						var scope =  keywordArgs.scope?keywordArgs.scope:dojo.global;
+						var scope = keywordArgs.scope?keywordArgs.scope:dojo.global;
 						try{
 							self._getItemsFromLoadedData(data);
 							self._loadFinished = true;
 							self._loadInProgress = false;
-							var item = self._getItemByIdentity(keywordArgs.identity);
+							item = self._getItemByIdentity(keywordArgs.identity);
 							if(keywordArgs.onItem){
 								keywordArgs.onItem.call(scope, item);
 							}
@@ -660,7 +807,7 @@ dojo.declare("dojo.data.ItemFileReadStore", null,{
 					getHandler.addErrback(function(error){
 						self._loadInProgress = false;
 						if(keywordArgs.onError){
-							var scope =  keywordArgs.scope?keywordArgs.scope:dojo.global;
+							var scope = keywordArgs.scope?keywordArgs.scope:dojo.global;
 							keywordArgs.onError.call(scope, error);
 						}
 					});
@@ -671,17 +818,17 @@ dojo.declare("dojo.data.ItemFileReadStore", null,{
 				self._getItemsFromLoadedData(self._jsonData);
 				self._jsonData = null;
 				self._loadFinished = true;
-				var item = self._getItemByIdentity(keywordArgs.identity);
+				item = self._getItemByIdentity(keywordArgs.identity);
 				if(keywordArgs.onItem){
-					var scope =  keywordArgs.scope?keywordArgs.scope:dojo.global;
+					scope = keywordArgs.scope?keywordArgs.scope:dojo.global;
 					keywordArgs.onItem.call(scope, item);
 				}
 			} 
 		}else{
 			// Already loaded.  We can just look it up and call back.
-			var item = this._getItemByIdentity(keywordArgs.identity);
+			item = this._getItemByIdentity(keywordArgs.identity);
 			if(keywordArgs.onItem){
-				var scope =  keywordArgs.scope?keywordArgs.scope:dojo.global;
+				scope = keywordArgs.scope?keywordArgs.scope:dojo.global;
 				keywordArgs.onItem.call(scope, item);
 			}
 		}
@@ -723,10 +870,35 @@ dojo.declare("dojo.data.ItemFileReadStore", null,{
 		//		Internal function to force a load of the store if it hasn't occurred yet.  This is required
 		//		for specific functions to work properly.  
 		var self = this;
+		//Do a check on the JsonFileUrl and crosscheck it.
+		//If it doesn't match the cross-check, it needs to be updated
+		//This allows for either url or _jsonFileUrl to he changed to
+		//reset the store load location.  Done this way for backwards 
+		//compatibility.  People use _jsonFileUrl (even though officially
+		//private.
+		if(this._jsonFileUrl !== this._ccUrl){
+			dojo.deprecated("dojo.data.ItemFileReadStore: ", 
+				"To change the url, set the url property of the store," +
+				" not _jsonFileUrl.  _jsonFileUrl support will be removed in 2.0");
+			this._ccUrl = this._jsonFileUrl;
+			this.url = this._jsonFileUrl;
+		}else if(this.url !== this._ccUrl){
+			this._jsonFileUrl = this.url;
+			this._ccUrl = this.url;
+		}
+
+		//See if there was any forced reset of data.
+		if(this.data != null && this._jsonData == null){
+			this._jsonData = this.data;
+			this.data = null;
+		}
+
 		if(this._jsonFileUrl){
 				var getArgs = {
-					url: self._jsonFileUrl, 
+					url: this._jsonFileUrl, 
 					handleAs: "json-comment-optional",
+					preventCache: this.urlPreventCache,
+					failOk: this.failOk,
 					sync: true
 				};
 			var getHandler = dojo.xhrGet(getArgs);
@@ -738,9 +910,14 @@ dojo.declare("dojo.data.ItemFileReadStore", null,{
 					//We mainly wanted to sync/wait here.
 					//TODO:  Revisit the loading scheme of this store to improve multi-initial
 					//request handling.
-					if (self._loadInProgress !== true && !self._loadFinished) {
+					if(self._loadInProgress !== true && !self._loadFinished){
 						self._getItemsFromLoadedData(data);
 						self._loadFinished = true;
+					}else if(self._loadInProgress){
+						//Okay, we hit an error state we can't recover from.  A forced load occurred
+						//while an async load was occurring.  Since we cannot block at this point, the best
+						//that can be managed is to throw an error.
+						throw new Error("dojo.data.ItemFileReadStore:  Unable to perform a synchronous load, an async load is in progress."); 
 					}
 				}catch(e){
 					console.log(e);
