@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Http_Response
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: ResponseTest.php 24593 2012-01-05 20:35:02Z matthew $
+ * @version    $Id$
  */
 
 /**
@@ -31,7 +31,7 @@ require_once 'Zend/Http/Response.php';
  * @category   Zend
  * @package    Zend_Http_Response
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Http
  * @group      Zend_Http_Response
@@ -249,7 +249,7 @@ class Zend_Http_ResponseTest extends PHPUnit_Framework_TestCase
 
         // Check we get an array if no code is passed
         $codes = Zend_Http_Response::responseCodeAsText();
-        $this->assertType('array', $codes);
+        $this->assertTrue(is_array($codes));
         $this->assertEquals('OK', $codes[200]);
     }
 
