@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Log
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: PriorityTest.php 24593 2012-01-05 20:35:02Z matthew $
+ * @version    $Id$
  */
 
 if (!defined('PHPUnit_MAIN_METHOD')) {
@@ -34,7 +34,7 @@ require_once 'Zend/Log/Filter/Priority.php';
  * @category   Zend
  * @package    Zend_Log
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Log
  */
@@ -72,7 +72,7 @@ class Zend_Log_Filter_PriorityTest extends PHPUnit_Framework_TestCase
             new Zend_Log_Filter_Priority('foo');
             $this->fail();
         } catch (Exception $e) {
-            $this->assertType('Zend_Log_Exception', $e);
+            $this->assertTrue($e instanceof Zend_Log_Exception);
             $this->assertRegExp('/must be an integer/i', $e->getMessage());
         }
     }
@@ -98,7 +98,7 @@ class Zend_Log_Filter_PriorityTest extends PHPUnit_Framework_TestCase
                 'filterParams' => array(),
             )));
         } catch(Exception $e) {
-            $this->assertType('Zend_Log_Exception', $e);
+            $this->assertTrue($e instanceof Zend_Log_Exception);
             $this->assertRegExp('/must be an integer/', $e->getMessage());
         }
     }
@@ -106,4 +106,4 @@ class Zend_Log_Filter_PriorityTest extends PHPUnit_Framework_TestCase
 
 if (PHPUnit_MAIN_METHOD == 'Zend_Log_Filter_PriorityTest::main') {
     Zend_Log_Filter_PriorityTest::main();
-}
\ No newline at end of file
+}
