@@ -15,13 +15,14 @@
  * @category   Zend
  * @package    Zend_Log
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: NullTest.php 3980 2007-03-15 21:38:38Z mike $
+ * @version    $Id$
  */
 
-/** PHPUnit_Framework_TestCase */
-require_once 'PHPUnit/Framework/TestCase.php';
+if (!defined('PHPUnit_MAIN_METHOD')) {
+    define('PHPUnit_MAIN_METHOD', 'Zend_Log_Writer_MockTest::main');
+}
 
 /** Zend_Log_Writer_Mock */
 require_once 'Zend/Log/Writer/Mock.php';
@@ -30,12 +31,18 @@ require_once 'Zend/Log/Writer/Mock.php';
  * @category   Zend
  * @package    Zend_Log
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: NullTest.php 3980 2007-03-15 21:38:38Z mike $
+ * @group      Zend_Log
  */
 class Zend_Log_Writer_MockTest extends PHPUnit_Framework_TestCase
 {
+    public static function main()
+    {
+        $suite  = new PHPUnit_Framework_TestSuite(__CLASS__);
+        $result = PHPUnit_TextUI_TestRunner::run($suite);
+    }
+
     public function testWrite()
     {
         $writer = new Zend_Log_Writer_Mock();
@@ -46,4 +53,18 @@ class Zend_Log_Writer_MockTest extends PHPUnit_Framework_TestCase
         $this->assertSame(array($fields), $writer->events);
     }
 
+    public function testFactory()
+    {
+        $cfg = array('log' => array('memory' => array(
+            'writerName' => "Mock"
+        )));
+
+        require_once 'Zend/Log.php';
+        $logger = Zend_Log::factory($cfg['log']);
+        $this->assertTrue($logger instanceof Zend_Log);
+    }
+}
+
+if (PHPUnit_MAIN_METHOD == 'Zend_Log_Writer_MockTest::main') {
+    Zend_Log_Writer_MockTest::main();
 }
